#!/usr/local/bin/perl
use strict;
use MyBench;
use DBI;
use Time::HiRes qw(gettimeofday tv_interval);
use String::Random qw(random_regex);

my($engine, $num_kids, $num_runs) = @ARGV;
$engine ||= 'innodb'; $num_kids ||= 10; $num_runs ||= 10000;

my $table = join '_', 'tbl', lc($engine);

my $callback = sub {
    my $id  = shift;
    my $dbh = DBI->connect('dbi:mysql:webdb;hostname=db-host', 'bench', '', 
                           { RaiseError => 1 });
    my $sth = $dbh->prepare("SELECT * FROM $table WHERE id = ?");

    # 親プロセスが HUP シグナルを送ってくるまで待機します。
    local $SIG{HUP} = sub { };
    sleep 600;

    my $i = 0;
    my @times = ();
    while ($i < $num_runs) {
        my $id = int(rand(100)) + 1;
        my $t0 = [gettimeofday];
        $sth->execute($id);
        my $t1 = tv_interval($t0, [gettimeofday]);
        push @times, $t1;
        $sth->finish();
        $i++;
    }
    $dbh->disconnect();
    my @r = ($id, scalar(@times), min(@times), max(@times), avg(@times), tot(@times));
    return @r;
};

my @results = MyBench::fork_and_work($num_kids, $callback);
MyBench::compute_results('select-pkey-'. $engine, @results);

exit;


