#!/usr/local/bin/perl
use strict;
use MyBench;
use DBI;
use Time::HiRes qw(gettimeofday tv_interval);
use String::Random qw(random_regex);

my($engine, $rows) = @ARGV;
$engine ||= 'innodb'; $rows ||= 100000;
my $table = join '_', 'tbl', lc($engine);

my $dbh = DBI->connect('dbi:mysql:webdb;hostname=db-host', 'bench', '', 
                       { RaiseError => 1, AutoCommit => 0 });
my $sth = $dbh->prepare("INSERT INTO $table (sub_id, text1, text2, created_on) VALUES(?, ?, ?, NOW())");

my $i = 0;
my $t0 = [gettimeofday];
while ($i < $rows) {
    my $sub_id = int(rand(100)) + 1;
    $sth->execute(
        $sub_id, 
        random_regex('[a-zA-Z]{30}'), 
        random_regex('[a-zA-Z]{512}')
    );
    $i++;
    if($i % 10000 == 0) {
        $dbh->commit;
    }
}
my $interval = tv_interval($t0, [gettimeofday]);
$sth->finish();

$dbh->commit;
$dbh->disconnect();

printf "ELAPSED TIME: %.3f\n", $interval;


